Crate ppx
Source - include_ppx(
macro or macro-stable) and nightly - Parse a macro at compile time from a file.
- include_ppx_string
macro or macro-stable - Parse a macro at compile time from a string.
- Error
- parse
- Parses a file using the templating engine.
- parse_cow
- Same as parse, but the parameters iterator has an item of
impl Into<Cow<str>>.
This is so that an empty iterator can be passed to parse. - parse_string
- Parses a file using the templating engine.
- parse_string_cow
- Same as parse_string, but the parameters iterator has an item of
impl Into<Cow<str>>.
This is so that an empty iterator can be passed to parse_string.